@@ -1436,9 +1436,59 @@ logLik.svyglm<-function(object,...){
    object$deviance
 }
 
-extractAIC.svyglm<-function(fit,...){
-    stop("svyglm not fitted by maximum likelihood")
+AIC.svyglm<-function(object,...,k=2){
+	if (length(list(...))){
+		do.call(rbind,lapply(list(object,...),extractAIC,k=k))
+    } else {
+	   extractAIC(object,k=k)
+    }
 }
+extractAIC.svyglm<-function(fit,scale,k=2,...){
+	if (length(attr(terms(fit),"factors"))){
+	    r<-regTermTest(fit, delete.response(formula(fit)), method="LRT")
+	    deltabar<-mean(r$lambda)
+	} else {
+	    r<-list(lambda=0)
+	    deltabar<-NaN
+	}
+	d<-fit$deviance
+	c(eff.p=sum(r$lambda), AIC=d+k*sum(r$lambda),deltabar=deltabar)
+}
+
+extractAIC.svrepglm<-extractAIC.svyglm
+
+BIC.svyglm<-function(object,...,maximal){
+	if (length(list(...))){
+		do.call(rbind,lapply(list(object,...),dBIC,modelM=maximal))
+    } else {
+	   dBIC(object,modelM=maximal)
+    }
+	
+	}
+	
+dBIC<-function(modela,modelM){
+	pm<-modela$rank
+	pM<-modelM$rank	
+
+	if (any(!(names(coef(modela))%in% names(coef(modelM))))){
+		stop("coefficients in model but not in maximal model")
+		}
+	index<-!(names(coef(modelM))%in% names(coef(modela)))
+	n<-1+modela$df.null	
+	if(any(index)){
+		wald<-coef(modelM)[index]%*%solve(vcov(modelM)[index,index],coef(modelM)[index])
+		detDelta<-det(solve(modelM$naive.cov[index,index,drop=FALSE],modelM$cov.unscaled[index,index,drop=FALSE]))
+		dbar<-detDelta^(1/(pM-pm))
+		nstar<-n/dbar	
+	}else {
+		wald<-0
+		detDelta<-1
+		dbar<-1
+		nstar=NaN
+		}
+	c(p=pm, BIC=wald+pm*log(n)+log(detDelta)+deviance(modelM),neff=nstar)
+	}	
+
 
 confint.svyglm<-function(object,parm,level=0.95,method=c("Wald","likelihood"),ddf=Inf,...){
   method<-match.arg(method)
@@ -1866,6 +1916,9 @@ model.frame.survey.design<-function(formula,...,drop=TRUE){
 model.frame.svyrep.design<-function(formula,...){
   formula$variables
 }
+model.frame.survey.design2<-function(formula,...){
+  formula$variables
+}
 
 .onLoad<-function(...){
   if (is.null(getOption("survey.lonely.psu")))
